@@ -97,6 +97,8 @@ int map_secret_after;
 // pulls out to 0.5x in 1 second
 #define M_ZOOMOUT       ((int) (FRACUNIT/1.02))
 
+#define PLAYERRADIUS    (16*(1<<MAPBITS)) // e6y
+
 // translates between frame-buffer and map distances
 #define FTOM(x) FixedMul(((x)<<16),scale_ftom)
 #define MTOF(x) (FixedMul((x),scale_mtof)>>16)
@@ -301,8 +303,8 @@ static void AM_restoreScaleAndLoc(void)
   }
   else
   {
-    m_x = plr->mo->x - m_w/2;
-    m_y = plr->mo->y - m_h/2;
+    m_x = (plr->mo->x >> FRACTOMAPBITS) - m_w/2;//e6y
+    m_y = (plr->mo->y >> FRACTOMAPBITS) - m_h/2;//e6y
   }
   m_x2 = m_x + m_w;
   m_y2 = m_y + m_h;
@@ -365,8 +367,8 @@ static void AM_findMinMaxBoundaries(void)
       max_y = vertexes[i].y;
   }
 
-  max_w = max_x - min_x;
-  max_h = max_y - min_y;
+  max_w = (max_x >>= FRACTOMAPBITS) - (min_x >>= FRACTOMAPBITS);//e6y
+  max_h = (max_y >>= FRACTOMAPBITS) - (min_y >>= FRACTOMAPBITS);//e6y
 
   min_w = 2*PLAYERRADIUS; // const? never changed?
   min_h = 2*PLAYERRADIUS;
@@ -443,8 +445,8 @@ static void AM_initVariables(void)
   break;
 
   plr = &players[pnum];
-  m_x = plr->mo->x - m_w/2;
-  m_y = plr->mo->y - m_h/2;
+  m_x = (plr->mo->x >> FRACTOMAPBITS) - m_w/2;//e6y
+  m_y = (plr->mo->y >> FRACTOMAPBITS) - m_h/2;//e6y
   AM_changeWindowLoc();
 
   // for saving & restoring
@@ -745,6 +747,10 @@ static void AM_rotate(fixed_t* x,  fixed_t* y, angle_t a, fixed_t xorig, fixed_t
 {
   fixed_t tmpx;
 
+  //e6y
+  xorig>>=FRACTOMAPBITS;
+  yorig>>=FRACTOMAPBITS;
+
   tmpx =
     FixedMul(*x - xorig,finecosine[a>>ANGLETOFINESHIFT])
       - FixedMul(*y - yorig,finesine[a>>ANGLETOFINESHIFT]);
@@ -788,8 +794,8 @@ static void AM_doFollowPlayer(void)
 {
   if (f_oldloc.x != plr->mo->x || f_oldloc.y != plr->mo->y)
   {
-    m_x = FTOM(MTOF(plr->mo->x)) - m_w/2;
-    m_y = FTOM(MTOF(plr->mo->y)) - m_h/2;
+    m_x = FTOM(MTOF(plr->mo->x >> FRACTOMAPBITS)) - m_w/2;//e6y
+    m_y = FTOM(MTOF(plr->mo->y >> FRACTOMAPBITS)) - m_h/2;//e6y
     m_x2 = m_x + m_w;
     m_y2 = m_y + m_h;
     f_oldloc.x = plr->mo->x;
@@ -1002,15 +1008,15 @@ static void AM_drawGrid(int color)
 
   // Figure out start of vertical gridlines
   start = m_x;
-  if ((start-bmaporgx)%(MAPBLOCKUNITS<<FRACBITS))
-    start += (MAPBLOCKUNITS<<FRACBITS)
-      - ((start-bmaporgx)%(MAPBLOCKUNITS<<FRACBITS));
+  if ((start-bmaporgx)%(MAPBLOCKUNITS<<MAPBITS))//e6y
+    start += (MAPBLOCKUNITS<<MAPBITS)//e6y
+      - ((start-bmaporgx)%(MAPBLOCKUNITS<<MAPBITS));//e6y
   end = m_x + m_w;
 
   // draw vertical gridlines
   ml.a.y = m_y;
   ml.b.y = m_y+m_h;
-  for (x=start; x<end; x+=(MAPBLOCKUNITS<<FRACBITS))
+  for (x=start; x<end; x+=(MAPBLOCKUNITS<<MAPBITS))//e6y
   {
     ml.a.x = x;
     ml.b.x = x;
@@ -1019,15 +1025,15 @@ static void AM_drawGrid(int color)
 
   // Figure out start of horizontal gridlines
   start = m_y;
-  if ((start-bmaporgy)%(MAPBLOCKUNITS<<FRACBITS))
-    start += (MAPBLOCKUNITS<<FRACBITS)
-      - ((start-bmaporgy)%(MAPBLOCKUNITS<<FRACBITS));
+  if ((start-bmaporgy)%(MAPBLOCKUNITS<<MAPBITS))//e6y
+    start += (MAPBLOCKUNITS<<MAPBITS)//e6y
+      - ((start-bmaporgy)%(MAPBLOCKUNITS<<MAPBITS));//e6y
   end = m_y + m_h;
 
   // draw horizontal gridlines
   ml.a.x = m_x;
   ml.b.x = m_x + m_w;
-  for (y=start; y<end; y+=(MAPBLOCKUNITS<<FRACBITS))
+  for (y=start; y<end; y+=(MAPBLOCKUNITS<<MAPBITS))//e6y
   {
     ml.a.y = y;
     ml.b.y = y;
@@ -1099,10 +1105,10 @@ static void AM_drawWalls(void)
   // draw the unclipped visible portions of all lines
   for (i=0;i<numlines;i++)
   {
-    l.a.x = lines[i].v1->x;
-    l.a.y = lines[i].v1->y;
-    l.b.x = lines[i].v2->x;
-    l.b.y = lines[i].v2->y;
+    l.a.x = lines[i].v1->x >> FRACTOMAPBITS;//e6y
+    l.a.y = lines[i].v1->y >> FRACTOMAPBITS;//e6y
+    l.b.x = lines[i].v2->x >> FRACTOMAPBITS;//e6y
+    l.b.y = lines[i].v2->y >> FRACTOMAPBITS;//e6y
 
     if (automapmode & am_rotate) {
       AM_rotate(&l.a.x, &l.a.y, ANG90-plr->mo->angle, plr->mo->x, plr->mo->y);
@@ -1355,8 +1361,8 @@ static void AM_drawPlayers(void)
         0,
         plr->mo->angle,
         mapcolor_sngl,      //jff color
-        plr->mo->x,
-        plr->mo->y
+        plr->mo->x >> FRACTOMAPBITS,//e6y
+        plr->mo->y >> FRACTOMAPBITS//e6y
       );
     else
       AM_drawLineCharacter
@@ -1366,8 +1372,8 @@ static void AM_drawPlayers(void)
         0,
         plr->mo->angle,
         mapcolor_sngl,      //jff color
-        plr->mo->x,
-        plr->mo->y);
+        plr->mo->x >> FRACTOMAPBITS,//e6y
+        plr->mo->y >> FRACTOMAPBITS);//e6y
     return;
   }
 
@@ -1378,9 +1384,9 @@ static void AM_drawPlayers(void)
       continue;
 
     if (playeringame[i]) {
-      fixed_t x = p->mo->x, y = p->mo->y;
+      fixed_t x = p->mo->x >> FRACTOMAPBITS, y = p->mo->y >> FRACTOMAPBITS;//e6y
       if (automapmode & am_rotate)
-  AM_rotate(&x, &y, ANG90-plr->mo->angle, plr->mo->x, plr->mo->y);
+  AM_rotate(&x, &y, ANG90-plr->mo->angle, plr->mo->x >> FRACTOMAPBITS, plr->mo->y >> FRACTOMAPBITS);
 
       AM_drawLineCharacter (player_arrow, NUMPLYRLINES, 0, p->mo->angle,
           p->powers[pw_invisibility] ? 246 /* *close* to black */
@@ -1409,7 +1415,7 @@ static void AM_drawThings(void)
     t = sectors[i].thinglist;
     while (t) // for all things in that sector
     {
-      fixed_t x = t->x, y = t->y;
+      fixed_t x = t->x >> FRACTOMAPBITS, y = t->y >> FRACTOMAPBITS;//e6y
 
       if (automapmode & am_rotate)
   AM_rotate(&x, &y, ANG90-plr->mo->angle, plr->mo->x, plr->mo->y);
@@ -1425,7 +1431,7 @@ static void AM_drawThings(void)
             (
               cross_mark,
               NUMCROSSMARKLINES,
-              16<<FRACBITS,
+              16<<MAPBITS,//e6y
               t->angle,
               mapcolor_rkey!=-1? mapcolor_rkey : mapcolor_sprt,
               x, y
@@ -1437,7 +1443,7 @@ static void AM_drawThings(void)
             (
               cross_mark,
               NUMCROSSMARKLINES,
-              16<<FRACBITS,
+              16<<MAPBITS,//e6y
               t->angle,
               mapcolor_ykey!=-1? mapcolor_ykey : mapcolor_sprt,
               x, y
@@ -1449,7 +1455,7 @@ static void AM_drawThings(void)
             (
               cross_mark,
               NUMCROSSMARKLINES,
-              16<<FRACBITS,
+              16<<MAPBITS,//e6y
               t->angle,
               mapcolor_bkey!=-1? mapcolor_bkey : mapcolor_sprt,
               x, y
@@ -1466,7 +1472,7 @@ static void AM_drawThings(void)
       (
         thintriangle_guy,
         NUMTHINTRIANGLEGUYLINES,
-        16<<FRACBITS,
+        16<<MAPBITS,//e6y
         t->angle,
 	t->flags & MF_FRIEND && !t->player ? mapcolor_frnd : 
 	/* cph 2006/07/30 - Show count-as-kills in red. */
