@@ -52,6 +52,7 @@
 #include "i_main.h"
 #include "i_video.h"
 #include "m_argv.h"
+#include "r_fps.h"
 #include "lprintf.h"
 
 #ifdef HAVE_CONFIG_H
@@ -77,6 +78,8 @@ int ticdup = 1;
 static int xtratics = 0;
 int              wanted_player_number;
 
+static boolean isExtraDDisplay = false;
+
 static void D_QuitNetGame (void);
 
 #ifndef HAVE_NET
@@ -259,6 +262,8 @@ boolean D_NetGetWad(const char* name)
 void NetUpdate(void)
 {
   static int lastmadetic;
+  if (isExtraDDisplay)
+    return;
   if (server) { // Receive network packets
     size_t recvlen;
     packet_header_t *packet = Z_Malloc(10000, PU_STATIC, NULL);
@@ -458,18 +463,34 @@ void TryRunTics (void)
 #endif
     runtics = (server ? remotetic : maketic) - gametic;
     if (!runtics) {
-      if (server) I_WaitForPacket(ms_to_next_tick);
-      else I_uSleep(ms_to_next_tick*1000);
+      if (!movement_smooth) {
+        if (server)
+          I_WaitForPacket(ms_to_next_tick);
+        else
+          I_uSleep(ms_to_next_tick*1000);
+      }
       if (I_GetTime() - entertime > 10) {
-        remotesend--;
-	if (server) {
-	  char buf[sizeof(packet_header_t)+1];
-	  packet_set((packet_header_t *)buf, PKT_RETRANS, remotetic);
-	  buf[sizeof(buf)-1] = consoleplayer;
-	  I_SendPacket((packet_header_t *)buf, sizeof buf);
-	}
+        if (server) {
+          char buf[sizeof(packet_header_t)+1];
+          remotesend--;
+          packet_set((packet_header_t *)buf, PKT_RETRANS, remotetic);
+          buf[sizeof(buf)-1] = consoleplayer;
+          I_SendPacket((packet_header_t *)buf, sizeof buf);
+        }
         M_Ticker(); return;
       }
+      //if ((displaytime) < (tic_vars.next-SDL_GetTicks()))
+      {
+        WasRenderedInTryRunTics = true;
+        if (V_GetMode() == VID_MODEGL ? 
+            movement_smooth : 
+            movement_smooth && gamestate==wipegamestate)
+        {
+          isExtraDDisplay = true;
+          D_Display();
+          isExtraDDisplay = false;
+        }
+      }
     } else break;
   }
 
@@ -480,6 +501,7 @@ void TryRunTics (void)
     if (advancedemo)
       D_DoAdvanceDemo ();
     M_Ticker ();
+    I_GetTime_SaveMS();
     G_Ticker ();
     P_Checksum(gametic);
     gametic++;
