@@ -1,14 +1,16 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
- *  PrBoom a Doom port merged with LxDoom and LSDLDoom
+ *  PrBoom: a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *  Copyright 2005, 2006 by
+ *  Florian Schulze, Colin Phipps, Neil Stevens, Andrey Budko
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +23,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -35,13 +37,13 @@
 /* killough 4/16/98: Cheat table structure */
 
 extern struct cheat_s {
-  const unsigned char *cheat;
+  const char *	cheat;
   const char *const deh_cheat;
-  enum { 
+  enum {
     always   = 0,
     not_dm   = 1,
     not_coop = 2,
-    not_demo = 4, 
+    not_demo = 4,
     not_menu = 8,
     not_deh = 16,
     not_net = not_dm | not_coop
@@ -53,6 +55,4 @@ extern struct cheat_s {
 
 boolean M_FindCheats(int key);
 
-extern int idmusnum;
-
 #endif
