@@ -445,6 +445,7 @@ int EV_DoFloor
     // new floor thinker
     rtn = 1;
     floor = Z_Malloc (sizeof(*floor), PU_LEVSPEC, 0);
+    memset(floor, 0, sizeof(*floor));
     P_AddThinker (&floor->thinker);
     sec->floordata = floor; //jff 2/22/98
     floor->thinker.function = T_MoveFloor;
@@ -748,6 +749,7 @@ int EV_BuildStairs
     // create new floor thinker for first step
     rtn = 1;
     floor = Z_Malloc (sizeof(*floor), PU_LEVSPEC, 0);
+    memset(floor, 0, sizeof(*floor));
     P_AddThinker (&floor->thinker);
     sec->floordata = floor;
     floor->thinker.function = T_MoveFloor;
@@ -828,6 +830,7 @@ int EV_BuildStairs
 
         // create and initialize a thinker for the next step
         floor = Z_Malloc (sizeof(*floor), PU_LEVSPEC, 0);
+        memset(floor, 0, sizeof(*floor));
         P_AddThinker (&floor->thinker);
 
         sec->floordata = floor; //jff 2/22/98
@@ -925,6 +928,7 @@ int EV_DoDonut(line_t*  line)
 
       //  Spawn rising slime
       floor = Z_Malloc (sizeof(*floor), PU_LEVSPEC, 0);
+      memset(floor, 0, sizeof(*floor));
       P_AddThinker (&floor->thinker);
       s2->floordata = floor; //jff 2/22/98
       floor->thinker.function = T_MoveFloor;
@@ -939,6 +943,7 @@ int EV_DoDonut(line_t*  line)
 
       //  Spawn lowering donut-hole pillar
       floor = Z_Malloc (sizeof(*floor), PU_LEVSPEC, 0);
+      memset(floor, 0, sizeof(*floor));
       P_AddThinker (&floor->thinker);
       s1->floordata = floor; //jff 2/22/98
       floor->thinker.function = T_MoveFloor;
@@ -986,6 +991,7 @@ int EV_DoElevator
     // create and initialize new elevator thinker
     rtn = 1;
     elevator = Z_Malloc (sizeof(*elevator), PU_LEVSPEC, 0);
+    memset(elevator, 0, sizeof(*elevator));
     P_AddThinker (&elevator->thinker);
     sec->floordata = elevator; //jff 2/22/98
     sec->ceilingdata = elevator; //jff 2/22/98
