@@ -242,6 +242,8 @@ enum {
 
 // killough 9/8/98: changed some fields to shorts,
 // for better memory usage (if only for cache).
+/* cph 2006/08/28 - move Prev[XYZ] fields to the end of the struct. Add any
+ * other new fields to the end, and make sure you don't break savegames! */
 
 typedef struct mobj_s
 {
@@ -341,13 +343,18 @@ typedef struct mobj_s
     // a linked list of sectors where this object appears
     struct msecnode_s* touching_sectorlist;                 // phares 3/14/98
 
+    fixed_t             PrevX;
+    fixed_t             PrevY;
+    fixed_t             PrevZ;
+
+    fixed_t             pad; // cph - needed so I can get the size unambiguously on amd64
+
     // SEE WARNING ABOVE ABOUT POINTER FIELDS!!!
 } mobj_t;
 
 // External declarations (fomerly in p_local.h) -- killough 5/2/98
 
 #define VIEWHEIGHT      (41*FRACUNIT)
-#define PLAYERRADIUS    (16*FRACUNIT)
 
 #define GRAVITY         FRACUNIT
 #define MAXMOVE         (30*FRACUNIT)
