@@ -1,14 +1,16 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
- *  PrBoom a Doom port merged with LxDoom and LSDLDoom
+ *  PrBoom: a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *  Copyright 2005, 2006 by
+ *  Florian Schulze, Colin Phipps, Neil Stevens, Andrey Budko
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +23,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -48,7 +50,7 @@ typedef struct
 {
   int originx, originy;  // Block origin, which has already accounted
   int patch;             // for the internal origin of the patch.
-} texpatch_t __attribute__((packed));
+} texpatch_t;
 
 //
 // Texture definition.
@@ -62,19 +64,17 @@ typedef struct
   int   next, index;     // killough 1/31/98: used in hashing algorithm
   // CPhipps - moved arrays with per-texture entries to elements here
   unsigned  widthmask;
-  //size_t    compositesize;
-  byte     *composite;
-  int hasSinglePatchAtOrigin;
-  //short    *columnlump;
-  //unsigned *columnofs;
   // CPhipps - end of additions
   short width, height;
   short patchcount;      // All the patches[patchcount] are drawn
   texpatch_t patches[1]; // back-to-front into the cached texture.
 } texture_t;
 
-// Retrieve column data for span blitting.
-const byte *R_GetTextureColumn(int tex, int col);
+extern int numtextures;
+extern texture_t **textures;
+
+
+const byte *R_GetTextureColumn(const rpatch_t *texpatch, int col);
 
 
 // I/O, setting up the stuff.
@@ -88,10 +88,13 @@ void R_PrecacheLevel (void);
 int R_FlatNumForName (const char* name);   // killough -- const added
 
 
-// Called by P_Ticker for switches and animations,
-// returns the texture number for the texture name.
-int R_TextureNumForName (const char *name);    // killough -- const added
-int R_CheckTextureNumForName (const char *name); 
+// R_*TextureNumForName returns the texture number for the texture name, or NO_TEXTURE if 
+//  there is no texture (i.e. "-") specified.
+/* cph 2006/07/23 - defined value for no-texture marker (texture "-" in the WAD file) */
+#define NO_TEXTURE 0
+int PUREFUNC R_TextureNumForName (const char *name);    // killough -- const added; cph - now PUREFUNC
+int PUREFUNC R_SafeTextureNumForName (const char *name, int snum);
+int PUREFUNC R_CheckTextureNumForName (const char *name);
 
 void R_InitTranMap(int);      // killough 3/6/98: translucency initialization
 int R_ColormapNumForName(const char *name);      // killough 4/4/98
@@ -103,6 +106,4 @@ extern const byte *main_tranmap, *tranmap;
 /* Proff - Added for OpenGL - cph - const char* param */
 void R_SetPatchNum(patchnum_t *patchnum, const char *name);
 
-extern texture_t **textures; // POPE
-
 #endif
