@@ -1,14 +1,16 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
- *  PrBoom a Doom port merged with LxDoom and LSDLDoom
+ *  PrBoom: a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *  Copyright 2005, 2006 by
+ *  Florian Schulze, Colin Phipps, Neil Stevens, Andrey Budko
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +23,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -36,8 +38,6 @@
 #pragma implementation "r_sky.h"
 #endif
 #include "r_sky.h"
-#include "r_data.h"
-#include "p_info.h"
 
 //
 // sky mapping
@@ -46,6 +46,10 @@ int skyflatnum;
 int skytexture;
 int skytexturemid;
 
+// e6y
+// It is necessary for fixing the no-sky problem in the third episode of the Requiem
+boolean isskytexture = false;
+
 //
 // R_InitSkyMap
 // Called whenever the view size changes.
@@ -54,54 +58,3 @@ void R_InitSkyMap (void)
 {
   skytexturemid = 100*FRACUNIT;
 }
-
-// called when the level starts to load the appropriate sky
-
-void R_StartSky()
-{
-  char *texturename=NULL;
-
-  // Set the sky map.
-  // First thing, we have a dummy sky texture name,
-  //  a flat. The data is in the WAD only because
-  //  we look for an actual index, instead of simply
-  //  setting one.
-
-  skyflatnum = R_FlatNumForName ( SKYFLATNAME );
-
-  // DOOM determines the sky texture to be used
-  // depending on the current episode, and the game version.
-  if (gamemode == commercial)
-    // || gamemode == pack_tnt   //jff 3/27/98 sorry guys pack_tnt,pack_plut
-    // || gamemode == pack_plut) //aren't gamemodes, this was matching retail
-    {
-      texturename = "SKY3";
-      if (gamemap < 12)
-        texturename = "SKY1";
-      else
-        if (gamemap < 21)
-          texturename = "SKY2";
-    }
-  else //jff 3/27/98 and lets not forget about DOOM and Ultimate DOOM huh?
-    switch (gameepisode)
-      {
-      case 1:
-        texturename = "SKY1";
-        break;
-      case 2:
-        texturename = "SKY2";
-        break;
-      case 3:
-        texturename = "SKY3";
-        break;
-      case 4: // Special Edition sky
-        texturename = "SKY4";
-        break;
-      }//jff 3/27/98 end sky setting fix
-
-  if(*info_skyname)
-    texturename=info_skyname;
-
-  skytexture = R_TextureNumForName (texturename);
-
-}
