@@ -2,12 +2,14 @@
  *-----------------------------------------------------------------------------
  *
  *
- *  PrBoom a Doom port merged with LxDoom and LSDLDoom
+ *  PrBoom: a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2000 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
+ *  Copyright 2005, 2006 by
+ *  Florian Schulze, Colin Phipps, Neil Stevens, Andrey Budko
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
@@ -39,6 +41,7 @@
 #include "s_sound.h"
 #include "i_sound.h"
 #include "i_system.h"
+#include "d_main.h"
 #include "r_main.h"
 #include "m_random.h"
 #include "w_wad.h"
@@ -62,11 +65,6 @@
 #define NORM_SEP 128
 #define S_STEREO_SWING (96<<FRACBITS)
 
-//jff 1/22/98 make sound enabling variables readable here
-extern int snd_card, mus_card;
-extern boolean nosfxparm, nomusicparm;
-//jff end sound enabling variables readable here
-
 const char* S_music_files[NUMMUSIC]; // cournia - stores music file names
 
 typedef struct
@@ -155,6 +153,17 @@ void S_Init(int sfxVolume, int musicVolume)
   }
 }
 
+void S_Stop(void)
+{
+  int cnum;
+
+  //jff 1/22/98 skip sound init if sound not enabled
+  if (snd_card && !nosfxparm)
+    for (cnum=0 ; cnum<numChannels ; cnum++)
+      if (channels[cnum].sfxinfo)
+        S_StopChannel(cnum);
+}
+
 //
 // Per level startup code.
 // Kills playing sounds at start of level,
@@ -162,16 +171,12 @@ void S_Init(int sfxVolume, int musicVolume)
 //
 void S_Start(void)
 {
-  int cnum,mnum;
+  int mnum;
 
   // kill all playing sounds at start of level
   //  (trust me - a good idea)
 
-  //jff 1/22/98 skip sound init if sound not enabled
-  if (snd_card && !nosfxparm)
-    for (cnum=0 ; cnum<numChannels ; cnum++)
-      if (channels[cnum].sfxinfo)
-        S_StopChannel(cnum);
+  S_Stop();
 
   //jff 1/22/98 return if music is not enabled
   if (!mus_card || nomusicparm)
@@ -299,11 +304,7 @@ void S_StartSoundAtVolume(void *origin_p, int sfx_id, int volume)
     sfx->usefulness = 1;
 
   // Assigns the handle to one of the channels in the mix/output buffer.
-  channels[cnum].handle = I_StartSound(sfx_id, cnum, volume, sep, pitch, priority);
-
-  // e6y: Crash with zero-length sounds.
-  // e6y: old code: channels[cnum].handle = I_StartSound(sfx_id, cnum, volume, sep, pitch, priority);
-  {
+  { // e6y: [Fix] Crash with zero-length sounds.
     int h = I_StartSound(sfx_id, cnum, volume, sep, pitch, priority);
     if (h != -1) channels[cnum].handle = h;
   }
@@ -373,6 +374,10 @@ void S_UpdateSounds(void* listener_p)
   if (!snd_card || nosfxparm)
     return;
 
+#ifdef UPDATE_MUSIC
+  I_UpdateMusic();
+#endif
+
   for (cnum=0 ; cnum<numChannels ; cnum++)
     {
       sfxinfo_t *sfx;
