@@ -504,7 +504,10 @@ static void ST_updateFaceWidget(void)
           // being attacked
           priority = 7;
 
-          if (plyr->health - st_oldhealth > ST_MUCHPAIN)
+          // haleyjd 10/12/03: classic DOOM problem of missing OUCH face
+          // was due to inversion of this test:
+          // if(plyr->health - st_oldhealth > ST_MUCHPAIN)
+          if(st_oldhealth - plyr->health > ST_MUCHPAIN)
             {
               st_facecount = ST_TURNCOUNT;
               st_faceindex = ST_calcPainOffset() + ST_OUCHOFFSET;
@@ -557,7 +560,10 @@ static void ST_updateFaceWidget(void)
       // getting hurt because of your own damn stupidity
       if (plyr->damagecount)
         {
-          if (plyr->health - st_oldhealth > ST_MUCHPAIN)
+          // haleyjd 10/12/03: classic DOOM problem of missing OUCH face
+          // was due to inversion of this test:
+          // if(plyr->health - st_oldhealth > ST_MUCHPAIN)
+          if(st_oldhealth - plyr->health > ST_MUCHPAIN)
             {
               priority = 7;
               st_facecount = ST_TURNCOUNT;
@@ -822,7 +828,7 @@ static void ST_diffDraw(void)
   ST_drawWidgets(false);
 }
 
-void ST_Drawer(boolean st_statusbaron, boolean refresh)
+void ST_Drawer(boolean statusbaron, boolean refresh)
 {
   /* cph - let status bar on be controlled
    * completely by the call from D_Display
@@ -832,7 +838,7 @@ void ST_Drawer(boolean st_statusbaron, boolean refresh)
 
   ST_doPaletteStuff();  // Do red-/gold-shifts from damage/items
 
-  if (st_statusbaron) {
+  if (statusbaron) {
     if (st_firsttime || (V_GetMode() == VID_MODEGL))
       ST_doRefresh();     /* If just after ST_Start(), refresh all */
     else
