@@ -1,14 +1,16 @@
-/* Emacs style mode select   -*- C++ -*- 
+/* Emacs style mode select   -*- C++ -*-
  *-----------------------------------------------------------------------------
  *
  *
- *  PrBoom a Doom port merged with LxDoom and LSDLDoom
+ *  PrBoom: a Doom port merged with LxDoom and LSDLDoom
  *  based on BOOM, a modified and improved DOOM engine
  *  Copyright (C) 1999 by
  *  id Software, Chi Hoang, Lee Killough, Jim Flynn, Rand Phares, Ty Halderman
  *  Copyright (C) 1999-2001 by
  *  Jess Haas, Nicolas Kalkhof, Colin Phipps, Florian Schulze
- *  
+ *  Copyright 2005, 2006 by
+ *  Florian Schulze, Colin Phipps, Neil Stevens, Andrey Budko
+ *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
@@ -21,7 +23,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  *  02111-1307, USA.
  *
  * DESCRIPTION:
@@ -41,18 +43,12 @@
 #include <stddef.h>
 #include <io.h>
 #endif
-#ifdef DREAMCAST
-#include <kos.h>
-#define O_BINARY 0
-uint32 open(const char *fn, int mode);
-#define lseek fs_seek
-#else
 #include <fcntl.h>
-#endif
-#include "i_system.h"
 
 #include "doomstat.h"
+#include "d_net.h"
 #include "doomtype.h"
+#include "i_system.h"
 
 #ifdef __GNUG__
 #pragma implementation "w_wad.h"
@@ -60,9 +56,6 @@ uint32 open(const char *fn, int mode);
 #include "w_wad.h"
 #include "lprintf.h"
 
-// From w_memcache.c
-void W_InitCache(void);
-
 //
 // GLOBALS
 //
